@@ -1,13 +1,14 @@
 package Net::SMS::CDYNE;
 
 use 5.008_001;
-our $VERSION = '0.13';
+our $VERSION = '0.14';
 
 use Any::Moose;
 use Any::Moose 'X::NonMoose';
 use XML::Simple;
 use Carp qw/croak cluck/;
 use Net::SMS::CDYNE::Response;
+use Encode;
 
 extends 'REST::Client';
 
@@ -41,6 +42,10 @@ sub do_cdyne_request {
         $headers->{'Content-Type'} = 'text/xml';
     }
 
+    # encode body
+    $body = encode_utf8($body)
+        if defined $body;
+    
     warn "Request: $uri\n" if $self->debug;
 
     $self->request($method, $uri, $body, $headers);
@@ -133,8 +138,24 @@ sub advanced_sms_send {
     my $uri = 'https://sms2.cdyne.com/sms.svc/SecureREST/AdvancedSMSsend';
 
     $args{LicenseKey} ||= $self->api_key;
-    my $num = delete $args{PhoneNumber};
+    my $nums = delete $args{PhoneNumbers};
+    $nums = [delete $args{PhoneNumber}] if $args{PhoneNumber};
     my $refid = delete $args{ReferenceID} || '';
+
+    my @subdoc = ();
+    foreach my $num (@$nums){
+        push(@subdoc, 
+            {
+                string => [
+                    {
+                        xmlns => 'http://schemas.microsoft.com/2003/10/Serialization/Arrays',
+                        content => $num,
+                    },
+                ]
+            }
+        );
+    }
+
     my $doc = {
         SMSAdvancedRequest => {
             xmlns => 'http://schemas.datacontract.org/2004/07/SmsWS',
@@ -148,14 +169,7 @@ sub advanced_sms_send {
                             AssignedDID => [ delete $args{AssignedDID} ],
                             StatusPostBackURL => [ delete $args{StatusPostBackURL} ],
                             ReferenceID => [ $refid ],
-                            PhoneNumbers => [ {
-                                string => [
-                                    {
-                                        xmlns => 'http://schemas.microsoft.com/2003/10/Serialization/Arrays',
-                                        content => $num,
-                                    },
-                                ],
-                            } ],
+                            PhoneNumbers => \@subdoc
                         },
                     ],
                 },
